BrowserServerOptions class
Constructors
-
BrowserServerOptions({List<
String> ? args, bool? chromiumSandbox, bool? devtools, String? downloadsPath, bool? headless, ListStringOrBool? ignoreDefaultArgs, Map<String, dynamic> ? proxy, num? timeout, String? tracesDir}) -
BrowserServerOptions.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
args
→ List<
String> ? -
final
- chromiumSandbox → bool?
-
final
- devtools → bool?
-
final
- downloadsPath → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headless → bool?
-
final
- ignoreDefaultArgs → ListStringOrBool?
-
final
-
proxy
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → num?
-
final
- tracesDir → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited