BrowserlessChromiumWebSocketApi class

Constructors

BrowserlessChromiumWebSocketApi({required String baseUrl, String? defaultToken})

Properties

baseUrl String
final
defaultToken String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({bool? blockAds, CDPLaunchOptionsOrString? launch, String? profile, num? timeout, String? token, String? trackingId, dynamic body}) → WebSocketChannel
Protocol: WebSocket Launch and connect to Chromium with a library like puppeteer or others that work over chrome-devtools-protocol.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
playwright({bool? blockAds, BrowserServerOptionsOrString? launch, String? profile, num? timeout, String? token, String? trackingId, dynamic body}) → WebSocketChannel
Protocol: WebSocket Connect to Chromium with any playwright style library.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited