BrowserlessDevtoolsWebSocketApi class
Methods
-
browser({bool? blockAds, CDPLaunchOptionsOrString? launch, String? profile, num? timeout, String? token, String? trackingId, dynamic body})
→ WebSocketChannel
-
Protocol: WebSocket
Connect to an already-running Chromium process with a library like
puppeteer, or others, that work over chrome-devtools-protocol. Chromium
must already be launched in order to not return a 404.
Summary: /devtools/browser/*
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
page({bool? blockAds, CDPLaunchOptionsOrString? launch, String? profile, num? timeout, String? token, String? trackingId, dynamic body})
→ WebSocketChannel
-
Protocol: WebSocket
Connect to an existing page in Chromium with a library like
chrome-remote-interface or others that work the page websocketDebugger
URL. You can get this unique URL by calling the /json/list API
or by finding the page's unique ID from your library of choice.
Summary: /devtools/page/*
-
toString()
→ String
-
A string representation of this object.
inherited