BrowserlessFunctionWebSocketApi class
Methods
-
connect({bool? blockAds, CDPLaunchOptionsOrString? launch, String? profile, num? timeout, String? token, String? trackingId, dynamic body})
→ WebSocketChannel
-
Protocol: WebSocket
Internally used by the POST /function API to connect the underlying client-side code to. Not intended for direct use but documented for completeness and to distinguish between other reconnect style calls.
Summary: /function/connect/*
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited