BrowserlessHttpApi class
REST API Client for Browserless v2.55.0
Constructors
- BrowserlessHttpApi({required String baseUrl, String? defaultToken})
Properties
- baseUrl → String
-
final
- chromium → BrowserlessChromiumHttpApi
-
latefinal
- defaultToken → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- json → BrowserlessJsonHttpApi
-
latefinal
- metrics → BrowserlessMetricsHttpApi
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
active(
{dynamic body}) → Future< String> - HTTP Method: GET Returns a simple "204" HTTP code, with no response, indicating that the service itself is up and running. Useful for liveliness probes or other external checks. Summary: /active
-
call(
{dynamic body}) → Future< String> - HTTP Method: GET Serves static files inside of this "static" directory. Content-types will vary depending on the type =of file being returned. Summary: /
-
config(
{dynamic body}) → Future< Map< String, dynamic> > - HTTP Method: GET Returns a JSON payload of the current system configuration. Summary: /config
-
kill(
{bool? blockAds, String? browserId, BrowserServerOptionsOrCDPLaunchOptionsOrString? launch, String? profile, num? timeout, String? token, String? trackingId, dynamic body}) → Future< String> -
HTTP Method: GET
Kill running sessions based on BrowserId or TrackingId.
Summary: /kill/+(
0-9a-zA-Z-_) -
meta(
{dynamic body}) → Future< Map< String, dynamic> > - HTTP Method: GET Returns a JSON payload of the current system versions, including the core API version. Summary: /meta
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pressure(
{dynamic body}) → Future< Map< String, dynamic> > - HTTP Method: GET Returns a JSON body of stats related to the pressure being exerted on the instance. This route is dynamic based upon the supplied "Accept" header, and will either return a human-readable message if the "Accept" header is set to "text/plain", or the default JSON body and a 200 HTTP code.
-
sessions(
{bool? blockAds, BrowserServerOptionsOrCDPLaunchOptionsOrString? launch, String? profile, num? timeout, String? token, String? trackingId, dynamic body}) → Future< List< BrowserlessSessionJSON> > - HTTP Method: GET Lists all currently running sessions and relevant meta-data excluding potentially open pages. Summary: /sessions
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited