BrowserlessMetricsHttpApi class

Constructors

BrowserlessMetricsHttpApi({required String baseUrl, String? defaultToken, required Client client})

Properties

baseUrl String
final
defaultToken String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({dynamic body}) Future<List<IBrowserlessStats>>
HTTP Method: GET Returns a list of metric details as far back as possible. Summary: /metrics
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
total({dynamic body}) Future<Map<String, dynamic>>
HTTP Method: GET Gets total metric details summed from the time the server started. Summary: /metrics/total

Operators

operator ==(Object other) bool
The equality operator.
inherited