BrowserlessSessionJSON class
Constructors
- BrowserlessSessionJSON({required String browser, required String browserId, required String id, required String initialConnectURL, required String killURL, required BrowserServerOptionsOrCDPLaunchOptions launchOptions, required num numbConnected, required ListStringOrString routePath, required num startedOn, required num timeAliveMs, String? trackingId, required String userDataDir})
-
BrowserlessSessionJSON.fromJson(Map<
String, dynamic> json) -
factory
Properties
- browser → String
-
final
- browserId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- initialConnectURL → String
-
final
- killURL → String
-
final
- launchOptions → BrowserServerOptionsOrCDPLaunchOptions
-
final
- numbConnected → num
-
final
- routePath → ListStringOrString
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedOn → num
-
final
- timeAliveMs → num
-
final
- trackingId → String?
-
final
- userDataDir → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited