CDPJSONPayload class

Constructors

CDPJSONPayload({required String description, required String devtoolsFrontendUrl, required String id, required String title, required String type, required String url, required String webSocketDebuggerUrl})
CDPJSONPayload.fromJson(Map<String, dynamic> json)
factory

Properties

description String
The description of the target. Generally the page's title.
final
devtoolsFrontendUrl String
The fully-qualified URL of the Devtools inspector app.
final
hashCode int
The hash code for this object.
no setterinherited
id String
A Unique Id for the underlying target.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
The title of the target. For pages this is the page's title.
final
type String
The type of target, generally "page" or "background_page".
final
url String
The current URL the target is consuming or visiting.
final
webSocketDebuggerUrl String
The target or page's WebSocket Debugger URL. Primarily used for legacy libraries to connect and inspect or remote automate this target.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited