webSocketDebuggerUrl property
The target or page's WebSocket Debugger URL. Primarily used for legacy libraries to connect and inspect or remote automate this target.
Implementation
final String webSocketDebuggerUrl;
The target or page's WebSocket Debugger URL. Primarily used for legacy libraries to connect and inspect or remote automate this target.
final String webSocketDebuggerUrl;