CDPLaunchOptions class

Constructors

CDPLaunchOptions({List<String>? args, Map<String, dynamic>? defaultViewport, bool? devtools, bool? dumpio, Map<String, dynamic>? headless, ListStringOrBool? ignoreDefaultArgs, bool? ignoreHTTPSErrors, bool? acceptInsecureCerts, num? slowMo, bool? stealth, num? timeout, String? userDataDir, bool? waitForInitialPage})
CDPLaunchOptions.fromJson(Map<String, dynamic> json)
factory

Properties

acceptInsecureCerts bool?
final
args List<String>?
final
defaultViewport Map<String, dynamic>?
final
devtools bool?
final
dumpio bool?
final
hashCode int
The hash code for this object.
no setterinherited
headless Map<String, dynamic>?
final
ignoreDefaultArgs ListStringOrBool?
final
ignoreHTTPSErrors bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slowMo num?
final
stealth bool?
final
timeout num?
final
userDataDir String?
final
waitForInitialPage bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited