expires property
Cookie expiration date as the number of seconds since the UNIX epoch. Set to -1 for
session cookies
Implementation
final num expires;
Cookie expiration date as the number of seconds since the UNIX epoch. Set to -1 for
session cookies
final num expires;