sourceOrigin property

String sourceOrigin
final

The site of the top-level URL the browser was visiting at the start of the request to the endpoint that set the cookie.

In Chrome, maps to the CDP's topLevelSite partition key.

Implementation

final String sourceOrigin;