FrameAddScriptTagOptions class

Constructors

FrameAddScriptTagOptions({String? url, String? path, String? content, String? type, String? id})
FrameAddScriptTagOptions.fromJson(Map<String, dynamic> json)
factory

Properties

content String?
JavaScript to be injected into the frame.
final
hashCode int
The hash code for this object.
no setterinherited
id String?
Sets the id of the script.
final
path String?
Path to a JavaScript file to be injected into the frame.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Sets the type of the script. Use module in order to load an ES2015 module.
final
url String?
URL of the script to be added.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited