GoToOptions class

Constructors

GoToOptions({String? referer, String? referrerPolicy, num? timeout, ListStringOrString? waitUntil, AbortSignal? signal})
GoToOptions.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
referer String?
If provided, it will take preference over the referer header value set by Page.setExtraHTTPHeaderspage.setExtraHTTPHeaders().
final
referrerPolicy String?
If provided, it will take preference over the referer-policy header value set by Page.setExtraHTTPHeaderspage.setExtraHTTPHeaders().
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signal AbortSignal?
A signal object that allows you to cancel the call.
final
timeout num?
Maximum wait time in milliseconds. Pass 0 to disable the timeout.
final
waitUntil ListStringOrString?
When to consider waiting succeeds. Given an array of event strings, waiting is considered to be successful after all events have been fired.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited