IBrowserlessStats class
Constructors
-
IBrowserlessStats({required num cpu, required num date, required num error, required num maxConcurrent, required num maxTime, required num meanTime, required num memory, required num minTime, required num queued, required num rejected, required List<
num> sessionTimes, required num successful, required num timedout, required num totalTime, required num unauthorized, required num unhealthy, required num units}) -
IBrowserlessStats.fromJson(Map<
String, dynamic> json) -
factory
Properties
- cpu → num
-
final
- date → num
-
final
- error → num
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConcurrent → num
-
final
- maxTime → num
-
final
- meanTime → num
-
final
- memory → num
-
final
- minTime → num
-
final
- queued → num
-
final
- rejected → num
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessionTimes
→ List<
num> -
final
- successful → num
-
final
- timedout → num
-
final
- totalTime → num
-
final
-
final
- unhealthy → num
-
final
- units → num
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited