ListStringOrBool class
Constructors
- ListStringOrBool.fromBool(bool? asBool)
- ListStringOrBool.fromJson(dynamic json)
-
factory
-
ListStringOrBool.fromListString(List<
String> ? asListString)
Properties
- asBool → bool?
-
final
-
asListString
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → dynamic -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited