ScrapeDebugOptions class

Constructors

ScrapeDebugOptions({bool? console, bool? cookies, bool? html, bool? network, bool? screenshot})
ScrapeDebugOptions.fromJson(Map<String, dynamic> json)
factory

Properties

console bool?
final
cookies bool?
final
hashCode int
The hash code for this object.
no setterinherited
html bool?
final
network bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshot bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited