ScreenshotClip class
Constructors
- ScreenshotClip({num? scale, required num width, required num height, required num x, required num y})
-
ScreenshotClip.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → num
-
the height of the element in pixels.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → num?
-
final
- width → num
-
the width of the element in pixels.
final
- x → num
-
final
- y → num
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited