ScreenshotOptions class

Constructors

ScreenshotOptions({bool? optimizeForSpeed, String? type, num? quality, bool? fromSurface, bool? fullPage, bool? omitBackground, String? path, ScreenshotClip? clip, String? encoding, bool? captureBeyondViewport})
ScreenshotOptions.fromJson(Map<String, dynamic> json)
factory

Properties

captureBeyondViewport bool?
Capture the screenshot beyond the viewport.
final
clip ScreenshotClip?
Specifies the region of the page/element to clip.
final
encoding String?
Encoding of the image.
final
fromSurface bool?
Capture the screenshot from the surface, rather than the view.
final
fullPage bool?
When true, takes a screenshot of the full page.
final
hashCode int
The hash code for this object.
no setterinherited
omitBackground bool?
Hides default white background and allows capturing screenshots with transparency.
final
optimizeForSpeed bool?
final
path String?
The file path to save the image to. The screenshot type will be inferred from file extension. If path is a relative path, then it is resolved relative to current working directory. If no path is provided, the image won't be saved to the disk.
final
quality num?
Quality of the image, between 0-100. Not applicable to png images.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited