StringOrNum class

Constructors

StringOrNum.fromJson(dynamic json)
factory
StringOrNum.fromNum(num? asNum)
StringOrNum.fromString(String? asString)

Properties

asNum num?
final
asString String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited