BrowserlessFunctionWebSocketApi class

Constructors

BrowserlessFunctionWebSocketApi({required String baseUrl, String? defaultToken})

Properties

baseUrl String
final
defaultToken String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect({bool? blockAds, CDPLaunchOptionsOrString? launch, String? profile, num? timeout, String? token, String? trackingId, dynamic body}) → WebSocketChannel
Protocol: WebSocket Internally used by the POST /function API to connect the underlying client-side code to. Not intended for direct use but documented for completeness and to distinguish between other reconnect style calls. Summary: /function/connect/*
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited