BrowserlessJsonHttpApi class
Methods
-
create({dynamic body})
→ Future<Map<String, dynamic>>
-
HTTP Method: PUT
Returns a JSON payload that acts as a pass-through to the DevTools /json/new HTTP API in Chromium.
Browserless mocks this payload so that remote clients can connect to the underlying "webSocketDebuggerUrl"
which will cause Browserless to start the browser and proxy that request into a blank page.
Summary: /json/new
-
list({dynamic body})
→ Future<List<CDPJSONPayload>>
-
HTTP Method: GET
Returns a JSON payload that acts as a pass-through to the DevTools /json/list HTTP API in Chromium and Chrome.
Browserless crafts this payload so that remote clients can connect to the underlying "webSocketDebuggerUrl"
properly, excluding any API tokens in that URL. If under authentication be sure to include your authorization.
Summary: /json/list
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
protocol({dynamic body})
→ Future<Map<String, dynamic>>
-
HTTP Method: GET
Returns Protocol JSON meta-data that Chrome and Chromium come with.
Summary: /json/protocol
-
toString()
→ String
-
A string representation of this object.
inherited
-
version({dynamic body})
→ Future<Map<String, dynamic>>
-
HTTP Method: GET
Returns a JSON payload that acts as a pass-through to the DevTools /json/version protocol in Chrome and Chromium.
Summary: /json/version