BrowserlessMetricsHttpApi class
Methods
-
call({dynamic body})
→ Future<List<IBrowserlessStats>>
-
HTTP Method: GET
Returns a list of metric details as far back as possible.
Summary: /metrics
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
total({dynamic body})
→ Future<Map<String, dynamic>>
-
HTTP Method: GET
Gets total metric details summed from the time the server started.
Summary: /metrics/total