BrowserlessWebSocketApi class

WebSocket API Client for Browserless v2.55.0

Constructors

BrowserlessWebSocketApi({required String baseUrl, String? defaultToken})

Properties

baseUrl String
final
chromium BrowserlessChromiumWebSocketApi
latefinal
defaultToken String?
final
devtools BrowserlessDevtoolsWebSocketApi
latefinal
function BrowserlessFunctionWebSocketApi
latefinal
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited