CDPJSONPayload class
Properties
-
description
→ String
-
The description of the target. Generally the page's title.
final
-
devtoolsFrontendUrl
→ String
-
The fully-qualified URL of the Devtools inspector app.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ String
-
A Unique Id for the underlying target.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
title
→ String
-
The title of the target. For pages this is the page's title.
final
-
type
→ String
-
The type of target, generally "page" or "background_page".
final
-
url
→ String
-
The current URL the target is consuming or visiting.
final
-
webSocketDebuggerUrl
→ String
-
The target or page's WebSocket Debugger URL. Primarily used for legacy
libraries to connect and inspect or remote automate this target.
final