CookieParam class

Cookie parameter object used to set cookies in the page-level cookies API.

Constructors

CookieParam({required String name, required String value, String? url, String? domain, String? path, bool? secure, bool? httpOnly, String? sameSite, num? expires, String? priority, String? sourceScheme, CookiePartitionKeyOrString? partitionKey})
CookieParam.fromJson(Map<String, dynamic> json)
factory

Properties

domain String?
Cookie domain.
final
expires num?
Cookie expiration date, session cookie if not set
final
hashCode int
The hash code for this object.
no setterinherited
httpOnly bool?
True if cookie is http-only.
final
name String
Cookie name.
final
partitionKey CookiePartitionKeyOrString?
Cookie partition key. In Chrome, it matches the top-level site the partitioned cookie is available in. In Firefox, it matches the source origin in the https://w3c.github.io/webdriver-bidi/#type-storage-PartitionKey PartitionKey.
final
path String?
Cookie path.
final
priority String?
Cookie Priority. Supported only in Chrome.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameSite String?
Cookie SameSite type.
final
secure bool?
True if cookie is secure.
final
sourceScheme String?
Cookie source scheme type. Supported only in Chrome.
final
url String?
The request-URI to associate with the setting of the cookie. This value can affect the default domain, path, and source scheme values of the created cookie.
final
value String
Cookie value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited