CookiePartitionKey class
Represents a cookie partition key in Chrome.
Constructors
- CookiePartitionKey({required String sourceOrigin, bool? hasCrossSiteAncestor})
-
CookiePartitionKey.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hasCrossSiteAncestor → bool?
-
Indicates if the cookie has any ancestors that are cross-site to
the topLevelSite.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceOrigin → String
-
The site of the top-level URL the browser was visiting at the start of the request
to the endpoint that set the cookie.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited