FrameAddStyleTagOptions class
Constructors
- FrameAddStyleTagOptions({String? url, String? path, String? content})
-
FrameAddStyleTagOptions.fromJson(Map<
String, dynamic> json) -
factory
Properties
- content → String?
-
Raw CSS content to be injected into the frame.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String?
-
The path to a CSS file to be injected into the frame.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String?
-
the URL of the CSS file to be added.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited