GoToOptions class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
referer
→ String?
-
If provided, it will take preference over the referer header value set by
Page.setExtraHTTPHeaderspage.setExtraHTTPHeaders().
final
-
referrerPolicy
→ String?
-
If provided, it will take preference over the referer-policy header value
set by
Page.setExtraHTTPHeaderspage.setExtraHTTPHeaders().
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
signal
→ AbortSignal?
-
A signal object that allows you to cancel the call.
final
-
timeout
→ num?
-
Maximum wait time in milliseconds. Pass 0 to disable the timeout.
final
-
waitUntil
→ ListStringOrString?
-
When to consider waiting succeeds. Given an array of event strings, waiting
is considered to be successful after all events have been fired.
final