PDFMargin class
Constructors
- PDFMargin({StringOrNum? top, StringOrNum? bottom, StringOrNum? left, StringOrNum? right})
-
PDFMargin.fromJson(Map<
String, dynamic> json) -
factory
Properties
- bottom → StringOrNum?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- left → StringOrNum?
-
final
- right → StringOrNum?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → StringOrNum?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited